@@ -33,7 +33,7 @@ trust_opts = [
                 help=_('Subset of trustor roles to be delegated to solum.')),
 ]
 cfg.CONF.register_opts(trust_opts)
-cfg.CONF.import_opt('auth_uri', 'keystonemiddleware.auth_token',
+cfg.CONF.import_opt('www_authenticate_uri', 'keystonemiddleware.auth_token',
                     group='keystone_authtoken')
 
 AUTH_OPTS = [
@@ -99,8 +99,9 @@ class KeystoneClientV3(object):
         else:
             # Import auth_token to have keystone_authtoken settings setup.
             importutils.import_module('keystonemiddleware.auth_token')
-            self.endpoint = cfg.CONF.keystone_authtoken.auth_uri.replace(
-                'v2.0', 'v3')
+            self.endpoint = \
+                cfg.CONF.keystone_authtoken.www_authenticate_uri.replace(
+                    'v2.0', 'v3')
 
         if self.context and self.context.trust_id:
             # Create a client with the specified trust_id, this
@@ -153,7 +154,7 @@ class KeystoneClientV3(object):
                 cfg.CONF, 'keystone_authtoken', **kwargs)
         elif self.context.auth_token is not None:
             kwargs['token'] = self.context.auth_token
-            kwargs['project_id'] = self.context.tenant
+            kwargs['project_id'] = self.context.project_id
             auth = identity.Token(
                 auth_url=kwargs['auth_url'],
                 token=kwargs['token'],
@@ -176,7 +177,7 @@ class KeystoneClientV3(object):
             self.context.auth_token = client.auth_ref.auth_token
             self.context.auth_url = self.endpoint
             self.context.user = client.auth_ref.user_id
-            self.context.tenant = client.auth_ref.project_id
+            self.context.project_id = client.auth_ref.project_id
             self.context.user_name = client.auth_ref.username
 
         return client
