@@ -20,16 +20,19 @@ from solum.common.rpc import service
 
 
 class API(service.API):
-    def __init__(self, transport=None, context=None):
+    def __init__(self, context=None):
         cfg.CONF.import_opt('topic', 'solum.deployer.config',
                             group='deployer')
-        super(API, self).__init__(transport, context,
+        super(API, self).__init__(context,
                                   topic=cfg.CONF.deployer.topic)
 
     def deploy(self, assembly_id, image_loc, image_name, ports):
         self._cast('deploy', assembly_id=assembly_id, image_loc=image_loc,
                    image_name=image_name, ports=ports)
 
+    def scale(self, assembly_id):
+        self._cast('scale', assembly_id=assembly_id)
+
     def destroy_assembly(self, assem_id):
         self._cast('destroy_assembly', assem_id=assem_id)
 
